import streamlit as st
import streamlit_authenticator as stauth
import yaml
from yaml.loader import SafeLoader
import os
import dashboard.via_upload as vu
import dashboard.show_labeled_tokens as slt
import dashboard.dashboard_visualizations as dv
import logging

logging.basicConfig(
    level=logging.INFO,
    format='%(asctime)s %(levelname)s %(message)s',
    handlers=[
        logging.FileHandler("app.log"),
        logging.StreamHandler()
    ]
)

logger = logging.getLogger(__name__)

# Set page config
st.set_page_config(page_title='AI in History', page_icon='📜', layout='wide', initial_sidebar_state='auto')

# Load configuration file
with open(os.path.join('secrets', 'config.yaml')) as file:
    config = yaml.load(file, Loader=SafeLoader)

# Create an authentication object
authenticator = stauth.Authenticate(
    config['credentials'],
    config['cookie']['name'],
    config['cookie']['key'],
    config['cookie']['expiry_days'],
    auto_hash=False
)

try:
    authenticator.login()
except Exception as e:
    st.error(e)

if st.session_state['authentication_status']:
    authenticator.logout('Logout', 'main')
    name = st.session_state['name']
    username = st.session_state['username']
    st.write(f'Welcome *{name}*')
    # set the username as a session variable
    st.session_state.username = username

    # Sidebar for navigation
    page = st.sidebar.selectbox("Choose a page", [
        "File Uploader",
        "Show Labeled Tokens",
        "Text Embeddings and Visualization",
    ])

    if page == "File Uploader":
        vu.get_file()
    elif page == "Show Labeled Tokens":
        slt.main()
    elif page == "Text Embeddings and Visualization":
        dv.main()

elif st.session_state['authentication_status'] is False:
    st.error('Username/password is incorrect')
elif st.session_state['authentication_status'] is None:
    st.warning('Please enter your username and password')

